summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/folder.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/folder.cpp')
-rw-r--r--umbrello/umbrello/folder.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/umbrello/umbrello/folder.cpp b/umbrello/umbrello/folder.cpp
index 7a4d11ab..127c3b34 100644
--- a/umbrello/umbrello/folder.cpp
+++ b/umbrello/umbrello/folder.cpp
@@ -157,8 +157,8 @@ void UMLFolder::removeAllViews() {
UMLView *v = NULL;
for (UMLViewListIt vit(m_diagrams); (v = vit.current()) != NULL; ++vit) {
// TODO ------------------ check this code - bad: calling back to UMLDoc::removeView()
- v->removeAllAssociations(); // note : It may not be aptqparent, but when we remove all associations
- // from a view, it also causes any UMLAssociations that lack tqparent
+ v->removeAllAssociations(); // note : It may not be apparent, but when we remove all associations
+ // from a view, it also causes any UMLAssociations that lack parent
// association widgets (but once had them) to remove themselves from
// this document.
UMLApp::app()->getDocument()->removeView(v, false);
@@ -249,7 +249,7 @@ void UMLFolder::saveToXMI(TQDomDocument& qDoc, TQDomElement& qElement) {
folderRoot.setAttribute("filename", m_folderFile);
folderRoot.setAttribute("mainModel", umldoc->URL().fileName());
folderRoot.setAttribute("parentId", ID2STR(m_pUMLPackage->getID()));
- folderRoot.setAttribute("tqparent", m_pUMLPackage->getFullyQualifiedName("::", true));
+ folderRoot.setAttribute("parent", m_pUMLPackage->getFullyQualifiedName("::", true));
saveContents(folderDoc, folderRoot);
folderDoc.appendChild(folderRoot);
TQTextStream stream(&file);